==> cloudwatch-1.60.0-sources.jar: software/amazon/awscdk/services/cloudwatch/MathExpressionOptions.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Configurable options for MathExpressions.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:02.864Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.MathExpressionOptions")
@software.amazon.jsii.Jsii.Proxy(MathExpressionOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MathExpressionOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Color for this metric when added to a Graph in a Dashboard.
     * <p>
     * Default: - Automatic color
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getColor() {
        return null;
    }

    /**
     * Label for this metric when added to a Graph in a Dashboard.
     * <p>
     * Default: - Expression value is used as label
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getLabel() {
        return null;
    }

    /**
     * The period over which the expression's statistics are applied.
     * <p>
     * This period overrides all periods in the metrics used in this
     * math expression.
     * <p>
     * Default: Duration.minutes(5)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getPeriod() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MathExpressionOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MathExpressionOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MathExpressionOptions> {
        private java.lang.String color;
        private java.lang.String label;
        private software.amazon.awscdk.core.Duration period;

        /**
         * Sets the value of {@link MathExpressionOptions#getColor}
         * @param color Color for this metric when added to a Graph in a Dashboard.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder color(java.lang.String color) {
            this.color = color;
            return this;
        }

        /**
         * Sets the value of {@link MathExpressionOptions#getLabel}
         * @param label Label for this metric when added to a Graph in a Dashboard.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder label(java.lang.String label) {
            this.label = label;
            return this;
        }

        /**
         * Sets the value of {@link MathExpressionOptions#getPeriod}
         * @param period The period over which the expression's statistics are applied.
         *               This period overrides all periods in the metrics used in this
         *               math expression.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder period(software.amazon.awscdk.core.Duration period) {
            this.period = period;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MathExpressionOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MathExpressionOptions build() {
            return new Jsii$Proxy(color, label, period);
        }
    }

    /**
     * An implementation for {@link MathExpressionOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MathExpressionOptions {
        private final java.lang.String color;
        private final java.lang.String label;
        private final software.amazon.awscdk.core.Duration period;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.color = this.jsiiGet("color", java.lang.String.class);
            this.label = this.jsiiGet("label", java.lang.String.class);
            this.period = this.jsiiGet("period", software.amazon.awscdk.core.Duration.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String color, final java.lang.String label, final software.amazon.awscdk.core.Duration period) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.color = color;
            this.label = label;
            this.period = period;
        }

        @Override
        public java.lang.String getColor() {
            return this.color;
        }

        @Override
        public java.lang.String getLabel() {
            return this.label;
        }

        @Override
        public software.amazon.awscdk.core.Duration getPeriod() {
            return this.period;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getColor() != null) {
                data.set("color", om.valueToTree(this.getColor()));
            }
            if (this.getLabel() != null) {
                data.set("label", om.valueToTree(this.getLabel()));
            }
            if (this.getPeriod() != null) {
                data.set("period", om.valueToTree(this.getPeriod()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudwatch.MathExpressionOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MathExpressionOptions.Jsii$Proxy that = (MathExpressionOptions.Jsii$Proxy) o;

            if (this.color != null ? !this.color.equals(that.color) : that.color != null) return false;
            if (this.label != null ? !this.label.equals(that.label) : that.label != null) return false;
            return this.period != null ? this.period.equals(that.period) : that.period == null;
        }

        @Override
        public int hashCode() {
            int result = this.color != null ? this.color.hashCode() : 0;
            result = 31 * result + (this.label != null ? this.label.hashCode() : 0);
            result = 31 * result + (this.period != null ? this.period.hashCode() : 0);
            return result;
        }
    }
}

==> cloudwatch-1.93.0-sources.jar: software/amazon/awscdk/services/cloudwatch/MathExpressionOptions.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Configurable options for MathExpressions.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:22.300Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.MathExpressionOptions")
@software.amazon.jsii.Jsii.Proxy(MathExpressionOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MathExpressionOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Color for this metric when added to a Graph in a Dashboard.
     * <p>
     * Default: - Automatic color
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getColor() {
        return null;
    }

    /**
     * Label for this metric when added to a Graph in a Dashboard.
     * <p>
     * Default: - Expression value is used as label
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getLabel() {
        return null;
    }

    /**
     * The period over which the expression's statistics are applied.
     * <p>
     * This period overrides all periods in the metrics used in this
     * math expression.
     * <p>
     * Default: Duration.minutes(5)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getPeriod() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MathExpressionOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MathExpressionOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MathExpressionOptions> {
        private java.lang.String color;
        private java.lang.String label;
        private software.amazon.awscdk.core.Duration period;

        /**
         * Sets the value of {@link MathExpressionOptions#getColor}
         * @param color Color for this metric when added to a Graph in a Dashboard.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder color(java.lang.String color) {
            this.color = color;
            return this;
        }

        /**
         * Sets the value of {@link MathExpressionOptions#getLabel}
         * @param label Label for this metric when added to a Graph in a Dashboard.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder label(java.lang.String label) {
            this.label = label;
            return this;
        }

        /**
         * Sets the value of {@link MathExpressionOptions#getPeriod}
         * @param period The period over which the expression's statistics are applied.
         *               This period overrides all periods in the metrics used in this
         *               math expression.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder period(software.amazon.awscdk.core.Duration period) {
            this.period = period;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MathExpressionOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MathExpressionOptions build() {
            return new Jsii$Proxy(color, label, period);
        }
    }

    /**
     * An implementation for {@link MathExpressionOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MathExpressionOptions {
        private final java.lang.String color;
        private final java.lang.String label;
        private final software.amazon.awscdk.core.Duration period;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.color = software.amazon.jsii.Kernel.get(this, "color", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.label = software.amazon.jsii.Kernel.get(this, "label", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.period = software.amazon.jsii.Kernel.get(this, "period", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Duration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String color, final java.lang.String label, final software.amazon.awscdk.core.Duration period) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.color = color;
            this.label = label;
            this.period = period;
        }

        @Override
        public final java.lang.String getColor() {
            return this.color;
        }

        @Override
        public final java.lang.String getLabel() {
            return this.label;
        }

        @Override
        public final software.amazon.awscdk.core.Duration getPeriod() {
            return this.period;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getColor() != null) {
                data.set("color", om.valueToTree(this.getColor()));
            }
            if (this.getLabel() != null) {
                data.set("label", om.valueToTree(this.getLabel()));
            }
            if (this.getPeriod() != null) {
                data.set("period", om.valueToTree(this.getPeriod()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudwatch.MathExpressionOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MathExpressionOptions.Jsii$Proxy that = (MathExpressionOptions.Jsii$Proxy) o;

            if (this.color != null ? !this.color.equals(that.color) : that.color != null) return false;
            if (this.label != null ? !this.label.equals(that.label) : that.label != null) return false;
            return this.period != null ? this.period.equals(that.period) : that.period == null;
        }

        @Override
        public final int hashCode() {
            int result = this.color != null ? this.color.hashCode() : 0;
            result = 31 * result + (this.label != null ? this.label.hashCode() : 0);
            result = 31 * result + (this.period != null ? this.period.hashCode() : 0);
            return result;
        }
    }
}
